"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toHaveDevDependency = void 0;
const toHaveDevDependency = (result, dependencyName, dependencyVersion) => {
    if (!result.assertJsonFileContent) {
        return {
            pass: false,
            message: () => {
                return `Expected ${result.toString()} to be a YeomanTest.RunResult`;
            },
        };
    }
    const hasPackageJson = result.fs.exists("package.json");
    if (!hasPackageJson) {
        return {
            pass: false,
            message: () => "Expected run result to contain a package.json file",
        };
    }
    const packageJsonString = result.fs.read("package.json");
    const packageJson = JSON.parse(packageJsonString);
    if (packageJson.devDependencies === undefined) {
        return {
            pass: false,
            message: () => {
                return "Expected run result package.json to have a devDependencies key";
            },
        };
    }
    const devDependencies = packageJson.devDependencies;
    const pass = dependencyVersion
        ?
            devDependencies[dependencyName] === dependencyVersion
        :
            devDependencies[dependencyName] !== undefined;
    let message = `Expected run result package.json to have devDependency ${dependencyName}`;
    if (dependencyVersion) {
        message += ` with version ${dependencyVersion}`;
    }
    return {
        pass,
        message: () => message,
    };
};
exports.toHaveDevDependency = toHaveDevDependency;
//# sourceMappingURL=toHaveDevDependency.matcher.js.map