"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_path_1 = __importDefault(require("node:path"));
const yeoman_test_1 = __importDefault(require("yeoman-test"));
const index_1 = require("./__tests__/__fixtures__/index");
describe("NodeModuleGenerator", () => {
    let result;
    beforeAll(async () => {
        result = await runWithAnswers(index_1.NODE_MODULE_GENERATOR_TEST_ANSWERS);
    });
    describe("package.json", () => {
        it("creates a package.json file", () => {
            result.assertFile("package.json");
        });
        it("fills in the name of the package", () => {
            result.assertJsonFileContent("package.json", { name: "test-package" });
        });
        it("fills in the version of the package", () => {
            result.assertJsonFileContent("package.json", { version: "0.0.1" });
        });
        it("fills in the description of the package", () => {
            result.assertJsonFileContent("package.json", {
                description: "This is a test package generated by Yeoman.",
            });
        });
        describe("scripts", () => {
            it("fills in an scripts section for the package", () => {
                result.assertJsonFileContent("package.json", {
                    scripts: {},
                });
            });
            it("stubs out a lint script for the package", () => {
                result.assertJsonFileContent("package.json", {
                    scripts: {
                        lint: "",
                    },
                });
            });
            it("stubs out a build script for the package", () => {
                result.assertJsonFileContent("package.json", {
                    scripts: {
                        build: "",
                    },
                });
            });
            it("stubs out a test script for the package", () => {
                result.assertJsonFileContent("package.json", {
                    scripts: {
                        test: "",
                    },
                });
            });
            it("stubs out a deploy script for the package", () => {
                result.assertJsonFileContent("package.json", {
                    scripts: {
                        deploy: "",
                    },
                });
            });
        });
        it("fills in the repository section of the package", () => {
            result.assertJsonFileContent("package.json", {
                repository: {
                    type: "git",
                    url: "git+https://github.com/chiubaka/test-package.git",
                },
            });
        });
        describe("keywords", () => {
            describe("when no keywords are provided", () => {
                let noKeywordsResult;
                beforeAll(async () => {
                    noKeywordsResult = await runWithAnswers(Object.assign(Object.assign({}, index_1.NODE_MODULE_GENERATOR_TEST_ANSWERS), { keywords: "" }));
                });
                it("does not include the keywords section", () => {
                    noKeywordsResult.assertNoJsonFileContent("package.json", {
                        keywords: [],
                    });
                });
            });
            describe("when keywords are provided", () => {
                it("fills in the keywords section of the package", () => {
                    result.assertJsonFileContent("package.json", {
                        keywords: ["test", "chiubaka-technologies"],
                    });
                });
                it("formats the keywords section properly", () => {
                    result.assertFileContent("package.json", '"keywords": ["test", "chiubaka-technologies"],');
                });
            });
        });
        it("fills in the author of the package", () => {
            result.assertJsonFileContent("package.json", {
                author: `Jon Smith <jon@example.com>`,
            });
        });
        it("fills in the license of the package", () => {
            result.assertJsonFileContent("package.json", {
                license: "UNLICENSED",
            });
        });
        it("fills in the bugs section of the package", () => {
            result.assertJsonFileContent("package.json", {
                bugs: {
                    url: "https://github.com/chiubaka/test-package/issues",
                },
            });
        });
        it("fills in the homepage of the package", () => {
            result.assertJsonFileContent("package.json", {
                homepage: "https://github.com/chiubaka/test-package#readme",
            });
        });
    });
});
const runWithAnswers = (answers) => {
    return yeoman_test_1.default.create(node_path_1.default.join(__dirname)).withPrompts(answers).run();
};
//# sourceMappingURL=NodeModuleGenerator.test.js.map